.. _decorators:

decorators
==========

.. module:: decorators
   :platform: Unix
   :synopsis: Decorator functions for processing wave and cube values.

Overview
--------

The decorators module contains decorator functions to validate inputs and enhance functionality for processing wave and cube values.

Functions
---------

.. autofunction:: wizard._utils.decorators.check_load_dc
.. autofunction:: wizard._utils.decorators.check_path
.. autofunction:: wizard._utils.decorators.add_method
.. autofunction:: wizard._utils.decorators.track_execution_time
.. autofunction:: wizard._utils.decorators.add_to_workflow
.. autofunction:: wizard._utils.decorators.check_limits